@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.023';
+our $VERSION='0.02401';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.023
+=head1 VERSION 0.02401
 
 =cut
 
@@ -32,13 +32,18 @@ Vote::Count
 
 has 'BallotSet' => ( is => 'ro', isa => 'HashRef', required => 1 );
 
-has 'Active' => (
-  is      => 'rw',
-  isa     => 'HashRef',
-  lazy    => 1,
-  builder => 'ResetActive',
+has 'BallotSetType' => (
+  is      => 'ro',
+  isa     => 'Str',
+  default =>  'rcv',
 );
 
+has 'Active' => (
+  is => 'rw',
+  isa => 'HashRef',
+  lazy => 1,
+  builder => 'ResetActive', );
+
 sub ResetActive ( $self ) { return dclone $self->BallotSet()->{'choices'} }
 
 sub SetActive ( $self, $active ) {
@@ -58,75 +63,62 @@ sub GetActive ( $self ) {
 }
 
 has TieBreakMethod => (
-  is       => 'rw',
-  isa      => 'Str',
+  is  => 'rw',
+  isa => 'Str',
   required => 0,
 );
 
 has 'PairMatrix' => (
-  is      => 'ro',
-  isa     => 'Object',
-  lazy    => 1,
-  builder => '_buildmatrix',
-);
+  is => 'ro',
+  isa => 'Object',
+  lazy => 1,
+  builder => '_buildmatrix', );
 
 sub _buildmatrix ( $self ) {
-  my $tiebreak =
-    defined( $self->TieBreakMethod() )
+  my $tiebreak = defined($self->TieBreakMethod())
     ? $self->TieBreakMethod()
     : 'none';
-  return Vote::Count::Matrix->new(
-    BallotSet      => $self->BallotSet(),
-    Active         => $self->Active(),
+  return  Vote::Count::Matrix->new(
+    BallotSet => $self->BallotSet(),
+    Active => $self->Active(),
     TieBreakMethod => $tiebreak,
-    LogTo          => $self->LogTo() . '_matrix',
-  );
+    LogTo => $self->LogTo() . '_matrix',
+  )
 }
 
-sub UpdatePairMatrix ( $self, $active = undef ) {
+sub UpdatePairMatrix ( $self, $active=undef ) {
   $active = $self->Active() unless defined $active;
   $self->{'PairMatrix'} = Vote::Count::Matrix->new(
     BallotSet => $self->BallotSet(),
-    Active    => $active
-  );
+    Active => $active
+  )
 }
 
 sub BUILD {
-  my $self = shift;
+  my $self      = shift;
   # Verbose Log
-  $self->{'LogV'} = localtime->cdate . "\n";
+  $self->{'LogV'} = localtime->cdate . "\n" ;
   # Debugging Log
   $self->{'LogD'} = qq/Vote::Count Version $VERSION\n/;
-  $self->{'LogD'} .= localtime->cdate . "\n";
+  $self->{'LogD'} .= localtime->cdate . "\n" ;
   # Terse Log
   $self->{'LogT'} = '';
 }
 
 # load the roles providing the underlying ops.
-with 'Vote::Count::Approval',
-  'Vote::Count::Borda',
-  'Vote::Count::Floor',
-  'Vote::Count::IRV',
-  'Vote::Count::Log',
-  'Vote::Count::Range',  
-  'Vote::Count::TieBreaker',
-  'Vote::Count::TopCount',
-  ;
+with  'Vote::Count::Approval',
+      'Vote::Count::Borda',
+      'Vote::Count::Floor',
+      'Vote::Count::IRV',
+      'Vote::Count::Log',      
+      'Vote::Count::TieBreaker',
+      'Vote::Count::TopCount',
+      ;
 
 sub VotesCast ( $self ) {
   return $self->BallotSet()->{'votescast'};
 }
 
-sub BallotSetType ( $self ) {
-  if( $self->BallotSet()->{'options'}{'rcv'} ) {
-    return 'rcv'
-  } elsif ( $self->BallotSet()->{'options'}{'range'} ) {
-    return 'range'
-  } else {
-    die "BallotSetType is undefined or unknown type.";
-  }
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -453,6 +445,12 @@ BallotSet: Get BallotSet
 
 
 
+=item *
+
+BallotSetType: Get the BallotSet Type (not implemented)
+
+
+
 =item *
 
 PairMatrix: Get a Matrix Object for the Active Set. Generated and cached on the first request.
